@@ -67,9 +67,9 @@ class Studio:
         self.main_window.setTitle(self.title)
         self.configuration_manager = ConfigurationManager()
         self.ocr_engines_manager = OcrEnginesManager(self.configuration_manager)
+        self.configuration_manager.loadConfiguration()
         self.ocr_engines_manager.makeEnginesFromFolder(self.configuration_manager.user_engines_folder)
         self.ocr_engines = self.ocr_engines_manager.ocr_engines
-        self.configuration_manager.loadConfiguration()
         self.source_images_selector = SourceImagesSelector()
         self.source_images_selector.connect('selection_changed', self.selectionChanged)
         self.source_images_icon_view = SourceImagesSelectorIconView(self.source_images_selector)
@@ -117,7 +117,8 @@ class Studio:
         parser.add_option('-i', '--images', dest = 'images',
                           action = 'append', type = 'string',
                           metavar = 'IMAGE1 [IMAGE2, ...]', default = [],
-                          help = 'images to be automatically added on start-up')
+                          help = 'images to be automatically added on start-up. '
+                                 'Use the option before every image path.')
         parser.add_option('-d', '--dir', dest = 'directory',
                           action = 'store', type = 'string',
                           help = 'directory with images to be added'
@@ -274,7 +275,9 @@ class Studio:
         file_open_dialog = widgetPresenter.FileDialog('select-folder')
         response = file_open_dialog.run()
         if response == gtk.RESPONSE_OK:
-            for folder in file_open_dialog.get_filenames():
+            filenames = file_open_dialog.get_filenames()
+            file_open_dialog.destroy()
+            for folder in filenames:
                 self.__addImagesToReviewer(lib.getImagesFromFolder(folder))
         file_open_dialog.destroy()
 
